==> am_mod_lbr_0_3.zip: am_mod_lbr_0_3/components/lbr/template/barnraiser_01/set_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<form action="index.php?amn=lbr_set_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="set_id" value="<?php if(isset($set['set_id'])) { echo $set['set_id'];}?>" />

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_set'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<label for="id_set_title"><?php echo $lang['txt_title'];?></label>
					<input id="id_set_title" class="input" type="text" name="set_title" size="24" value="<?php if (isset($set['set_title'])) { echo $set['set_title'];}?>" />
					&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<p>
					<label for="id_set_synopsis"><?php echo $lang['txt_synopsis'];?></label>
					<textarea id="id_set_synopsis" name="set_synopsis" cols="22" rows="2"><?php if (isset($set['set_synopsis'])) { echo $set['set_synopsis'];}?></textarea>
					<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<script type="text/javascript">
				function showMembershipTypes(id) {
					var displaystate = 'none';
					
					if (id.value == 4) {
						displaystate = 'block';
					}
					
					objShowHide('id_membership_type', displaystate);
				}
				</script>
				
				<p>
					<label for="id_set_type"><?php echo $lang['txt_participation'];?></label>
					<?php
					// if this is set to membership type and we do not have permission to change this
					// we just print out that
					if (isset($set['set_type']) && $set['set_type'] == $library_config['type']['membership_type'] && $_SESSION['user_core_permission'] ^ $core_config['resource']['user']['mem_visible']) {
						echo $lang['set_type'][$set['set_type']];
						if (!empty($set['membership_type_ids'])) {
							$prnt = "<br /><i>(";
							foreach ($set['membership_type_ids'] as $keymt => $mt):
								$prnt .= $lang['membership_type'][$mt['membership_type_id']] . ", ";
							endforeach;

							$prnt = substr ($prnt, 0, -2) . ")</i><br />";
							echo $prnt;
						}
					}
					else {
					?>
					<select id="id_set_type" name="set_type" style="width:160px;" onChange="javascript:showMembershipTypes(this);">
						<?php
						if (isset($library_config['type'])) {
						foreach ($library_config['type'] as $key => $i):

						// check to see if we are allowed to set membership types
						if ($i == $library_config['type']['membership_type'] && $_SESSION['user_core_permission'] ^ $core_config['resource']['user']['mem_visible']) {
							break;
						}
						
						$selected = "";
						if (isset($set['set_type']) && $set['set_type'] == $key) {
							$selected = "selected=\"selected\"";
						}
						?>
						<option value="<?php echo $i;?>" <?php echo $selected;?>><?php echo $lang['set_type'][$i];?></option>
						<?php
						endforeach;
						}
						?>
					</select>
					<?php }?>
				</p>
				
				<?php
				if ($_SESSION['user_core_permission'] & $core_config['resource']['user']['mem_visible']) {
				?>
				<p id="id_membership_type">
					<?php
					if (isset($lang['membership_type'])) {
					foreach ($lang['membership_type'] as $key => $i):
						
					$selected = "";
					
					if (!empty($set['membership_type_ids'])) {					
						foreach ($set['membership_type_ids'] as $keymt => $mt):
							if ($mt['membership_type_id'] == $key) {
								$selected = "checked=\"checked\"";
								break;
							}
						endforeach;
					}
					?>
					<label></label>
					<input type="checkbox" name="membership_types[]" value="<?php echo $key;?>" <?php echo $selected;?> />&nbsp;<?php echo $i;?><br />
					<?php
					endforeach;
					}
					?>
				</p>
				
				<script type="text/javascript">
					var id = document.getElementById('id_set_type');
					showMembershipTypes(id);
				</script>
				<?php }?>
				
				<?php if (!isset($set['set_id'])) { ?>
					<label for="identity_id"><?php echo $lang['txt_my_identity']; ?></label>
					<select name="identity_id">
						<?php foreach($identities as $i): ?>
							<?php 
								$selected = '';
								if (!empty($_REQUEST['identity_id'])) {
									if ($i['identity_id'] == $_REQUEST['identity_id']) {
										$selected = "selected=\"selected\"";
									}
								}
							?>
							<option value="<?php echo $i['identity_id']; ?>" <?php echo $selected; ?>><?php echo $i['identity_name']; ?></option>
						<?php endforeach; ?>
					</select>
				<?php  } ?>
				
					
				<?php
				if (isset($images)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<tr>
						<td valign="top">
							<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />	
						</td>
						<td valign="top" width="100%">
							<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
								<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
								<?php
								$img_divs = "";
								foreach($images as $key => $i):
								$display_state = "none";
								$selected = "";
								if (isset($set['file_id']) && $set['file_id'] == $i['file_id']) {
									$selected = "selected=\"selected\"";
									$display_state = "block";
								}
								?>
								<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
								<?php
								$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['file_type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
								endforeach;
								?>
							</select>
						</td>
						<td valign="top" align="right">
							<?php echo $img_divs;?>
						</td>	
					</tr>
				</table>
				<?php }?>
				
				<p>
					<label for="id_set_level"><?php echo $lang['txt_publish'];?></label>
					<select id="id_set_level" name="level_id" style="width:160px;">
						<?php
						if (isset($lang['set_level'])) {
						foreach ($lang['set_level'] as $key => $i):
						
						$selected = "";
						if (isset($set['level_id']) && $set['level_id'] == $key) {
							$selected = "selected=\"selected\"";
						}
						?>
						<option value="<?php echo $key;?>" <?php echo $selected;?>><?php echo $i;?></option>
						<?php
						endforeach;
						}
						?>
					</select>
				</p>
						
		
				<?php
				if (count($lang['arr_lang_name']) > 1) {
				?>
				<p>
					<label for="id_languages"><?php echo $lang['txt_language'];?></label>
					<select name="language_id">
					<?php 
					foreach($lang['arr_lang_name'] as $key => $i): 
					?>
						<option value="<?php echo $key;?>" <?php if(isset($set) && $set['language_id'] == $key) echo "selected=\"selected\"";?>><?php echo ucFirst($lang['arr_lang_name'][$key]);?></option>
					<?php
					endforeach;
					?>
					</select>
				</p>
				<?php }?>
				
				<?php
				if (isset($set) && !empty($lang['set_status'])) {
				?>
				<p>
					<label for="id_status"><?php echo $lang['txt_status'];?></label>
					<select name="status_id">
						<?php foreach($lang['set_status'] as $key => $i): 
						if (isset($lang['set_status'][$key])) {
					
						?>
						<option value="<?php echo $key;?>" <?php if(isset($set['status_id']) && $set['status_id'] == $i) { echo "selected=\"selected\"";}?>><?php echo $lang['set_status'][$key];?></option>
						<?php 
						}
						endforeach;
						?>
					</select>
				</p>
				<?php }?>
				
				<?php
				if (isset($library_config['resource']['set'])) {
				?>
				
				<hr />
				
				<p>
					<b><?php echo $lang['hdr_permissions'];?></b><br />
				</p>
		
				<?php
				foreach($library_config['resource']['set'] as $rekey => $re):
				?>
				
				<?php
				$checked = "";
				if (isset($set['set_permission'])) {
					if ($set['set_permission'] & $library_config['resource']['set'][$rekey]) {
						$checked = "checked=\"checked\"";
					}
				}
				?>
				<p>
					<input type="checkbox" name="permission[set][<?php echo $re;?>]" value="<?php echo $re;?>" <?php echo $checked;?> />&nbsp;
					<?php echo $lang['resource'][$module_prefix]['set'][$re];?><br />
				</p>
				<?php
				endforeach;
				?>		
				<?php }?>
				
				
				<hr />
							
				<p align="right">
					<?php
					if (isset($allow_spellcheck)) {
					?>
					<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
					<?php }?>
					
					<input type="submit" name="save_set" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
					<br />
				</p>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_ownership'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				
				<p>
					<?php echo $lang['txt_owner_intro'];?><br />
				</p>
				
				<?php
				if (isset($editors)) {
				?>
				<p>
					<label for="id_user_id"><?php echo $lang['txt_new_owner'];?></label>
					<select id="id_user_id" name="user_id" style="width:160px;">
						<?php
						foreach ($editors as $key => $i):
						?>
						<option value="<?php echo $i['user_id'];?>"><?php echo $i['identity_nic'];?></option>
						<?php
						endforeach;
						?>
					</select>
				</p>
				
				<hr />
					
				<p align="right">
					<input name="update_ownership" type="submit" class="input_submit" value="<?php echo $lang['sub_resign'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_starting_a_set'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_wiki_set_create_intro'];?><br />
				</p>
			</div>
		</div>
	</div>

	<?php
	if (isset($set)) {
	?>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_tags'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_tags'];?></b><br />
					<?php
					if (isset($tags)) {
					$prnt = "";
					foreach($tags as $key => $i):
						$prnt .= $i['tag_body'] . "<sup><a href='index.php?amn=lbr_set_edit&amp;set_id=" . $set['set_id'] . "&amp;edit_tag=" . $i['tag_id'] . "&amp;user_id=" . $i['item_id'] . "' style='text-decoration:none;'>&#43;</a></sup> ";
					endforeach;
					echo $prnt;
					}
					?>
				</p>
				
				<table cellspacing="1" cellpadding="0" border="0" width="100%">
					<tr>
						<td>
							<input type="hidden" name="tag_id" value="<?php if (isset($tag)) { echo $tag['tag_id'];}?>" />
							<input type="text" class="input1" name="tag_body" size="10" value="<?php if (isset($tag)) { echo $tag['tag_body'];}?>" /><br />
						</td>	
						<td nowrap="nowrap" align="right">
							<input type="submit" name="insert_tag" class="input_submit" style="font-size:60%;" value="OK" /> 
							<input type="submit" name="delete_tag" class="input_submit" style="font-size:60%;" value="DEL" /><br />
						</td>					
					</tr>				
				</table>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_page_default'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($pages)) {
				?>
				<table cellspacing="2" cellpadding="2" width="100%" border="0">
					<?php
					foreach ($pages as $key => $i):
					?>
					<tr>
						<td valign="top">
							<b><?php echo $i['page_title'];?></b><br />
							<?php echo $i['page_name'];?><br />
						</td>
						<td valign="top">
							<?php
							$checked = "";
							
							if ($set['default_page_id'] == $i['page_id']) {
								$checked = "checked=\"checked\"";
							}
							?>
							<input type="radio" name="default_page_id" value="<?php echo $i['page_id'];?>" <?php echo $checked;?> /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="set_default_page_id" class="input_submit" value="<?php echo $lang['sub_default_page_id'];?>" />
					<br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
<?php }?>
</div>		
</form>

==> am_mod_lbr_0_5.zip: am_mod_lbr_0_5/components/lbr/template/barnraiser_01/set_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<form action="index.php?amn=lbr_set_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="set_id" value="<?php if(isset($set['set_id'])) { echo $set['set_id'];}?>" />

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_set'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<label for="id_set_title"><?php echo $lang['txt_title'];?></label>
					<input id="id_set_title" class="input" type="text" name="set_title" size="24" value="<?php if (isset($set['set_title'])) { echo $set['set_title'];}?>" />
					&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<p>
					<label for="id_set_synopsis"><?php echo $lang['txt_synopsis'];?></label>
					<textarea id="id_set_synopsis" name="set_synopsis" cols="22" rows="2"><?php if (isset($set['set_synopsis'])) { echo $set['set_synopsis'];}?></textarea>
					<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<script type="text/javascript">
				function showMembershipTypes(id) {
					var displaystate = 'none';
					
					if (id.value == 4) {
						displaystate = 'block';
					}
					
					objShowHide('id_membership_type', displaystate);
				}
				</script>
				
				<p>
					<label for="id_set_type"><?php echo $lang['txt_participation'];?></label>
					<?php
					// if this is set to membership type and we do not have permission to change this
					// we just print out that
					if (isset($set['set_type']) && $set['set_type'] == $library_config['type']['membership_type'] && $core_config['resource']['user']['mem_visible'] & ~$_SESSION['user_core_permission']) {
						echo $lang['set_type'][$set['set_type']];
						if (!empty($set['membership_type_ids'])) {
							$prnt = "<br /><i>(";
							foreach ($set['membership_type_ids'] as $keymt => $mt):
								$prnt .= $lang['membership_type'][$mt['membership_type_id']] . ", ";
							endforeach;

							$prnt = substr ($prnt, 0, -2) . ")</i><br />";
							echo $prnt;
						}
					}
					else {
					?>
					<select id="id_set_type" name="set_type" style="width:160px;" onChange="javascript:showMembershipTypes(this);">
						<?php
						if (isset($library_config['type'])) {
						foreach ($library_config['type'] as $key => $i):

						// check to see if we are allowed to set membership types
						if ($i == $library_config['type']['membership_type'] && $core_config['resource']['user']['mem_visible'] & ~$_SESSION['user_core_permission']) {
							break;
						}
						
						$selected = "";
						if (isset($set['set_type']) && $set['set_type'] == $i) {
							$selected = "selected=\"selected\"";
						}
						?>
						<option value="<?php echo $i;?>" <?php echo $selected;?>><?php echo $lang['set_type'][$i];?></option>
						<?php
						endforeach;
						}
						?>
					</select>
					<?php }?>
				</p>
				
				<?php
				if ($_SESSION['user_core_permission'] & $core_config['resource']['user']['mem_visible']) {
				?>
				<p id="id_membership_type">
					<?php
					if (isset($lang['membership_type'])) {
					foreach ($lang['membership_type'] as $key => $i):
						
					$selected = "";
					
					if (!empty($set['membership_type_ids'])) {					
						foreach ($set['membership_type_ids'] as $keymt => $mt):
							if ($mt['membership_type_id'] == $key) {
								$selected = "checked=\"checked\"";
								break;
							}
						endforeach;
					}
					?>
					<label></label>
					<input type="checkbox" name="membership_types[]" value="<?php echo $key;?>" <?php echo $selected;?> />&nbsp;<?php echo $i;?><br />
					<?php
					endforeach;
					}
					?>
				</p>
				
				<script type="text/javascript">
					var id = document.getElementById('id_set_type');
					showMembershipTypes(id);
				</script>
				<?php }?>
				
				<?php if (!isset($set['set_id'])) { ?>
					<label for="id_identity_id"><?php echo $lang['txt_my_identity']; ?></label>
					<select id="id_identity_id" name="identity_id">
						<?php foreach($identities as $i): ?>
							<?php 
								$selected = '';
								if (!empty($_REQUEST['identity_id'])) {
									if ($i['identity_id'] == $_REQUEST['identity_id']) {
										$selected = "selected=\"selected\"";
									}
								}
							?>
							<option value="<?php echo $i['identity_id']; ?>" <?php echo $selected; ?>><?php echo $i['identity_name']; ?></option>
						<?php endforeach; ?>
					</select>
				<?php  } ?>
				
					
				<?php
				if (isset($images)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<tr>
						<td valign="top">
							<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />	
						</td>
						<td valign="top" width="100%">
							<select style="width:100px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
								<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
								<?php
								$img_divs = "";
								foreach($images as $key => $i):
								$display_state = "none";
								$selected = "";
								if (isset($set['file_id']) && $set['file_id'] == $i['file_id']) {
									$selected = "selected=\"selected\"";
									$display_state = "block";
								}
								?>
								<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
								<?php
								$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['file_type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
								endforeach;
								?>
							</select>
						</td>
						<td valign="top" align="right">
							<?php echo $img_divs;?>
						</td>	
					</tr>
				</table>
				<?php }?>
				
				<p>
					<label for="id_set_level"><?php echo $lang['txt_publish'];?></label>
					<select id="id_set_level" name="level_id" style="width:160px;">
						<?php
						if (isset($lang['set_level'])) {
						foreach ($lang['set_level'] as $key => $i):
						
						$selected = "";
						if (isset($set['level_id']) && $set['level_id'] == $key) {
							$selected = "selected=\"selected\"";
						}
						?>
						<option value="<?php echo $key;?>" <?php echo $selected;?>><?php echo $i;?></option>
						<?php
						endforeach;
						}
						?>
					</select>
				</p>
						
		
				<?php
				if (count($lang['arr_lang_name']) > 1) {
				?>
				<p>
					<label for="id_languages"><?php echo $lang['txt_language'];?></label>
					<select name="language_id">
					<?php 
					foreach($lang['arr_lang_name'] as $key => $i): 
					?>
						<option value="<?php echo $key;?>" <?php if(isset($set) && $set['language_id'] == $key) echo "selected=\"selected\"";?>><?php echo ucFirst($lang['arr_lang_name'][$key]);?></option>
					<?php
					endforeach;
					?>
					</select>
				</p>
				<?php }?>
				
				<?php
				if (isset($set) && !empty($lang['set_status'])) {
				?>
				<p>
					<label for="id_status"><?php echo $lang['txt_status'];?></label>
					<select name="status_id">
						<?php foreach($lang['set_status'] as $key => $i): 
						if (isset($lang['set_status'][$key])) {
					
						?>
						<option value="<?php echo $key;?>" <?php if(isset($set['status_id']) && $set['status_id'] == $i) { echo "selected=\"selected\"";}?>><?php echo $lang['set_status'][$key];?></option>
						<?php 
						}
						endforeach;
						?>
					</select>
				</p>
				<?php }?>
				
				<?php
				if (isset($library_config['resource']['set'])) {
				?>
				
				<hr />
				
				<p>
					<b><?php echo $lang['hdr_permissions'];?></b><br />
				</p>
		
				<?php
				foreach($library_config['resource']['set'] as $rekey => $re):
				?>
				
				<?php
				$checked = "";
				if (isset($set['set_permission'])) {
					if ($set['set_permission'] & $library_config['resource']['set'][$rekey]) {
						$checked = "checked=\"checked\"";
					}
				}
				?>
				<p>
					<input type="checkbox" name="permission[set][<?php echo $re;?>]" value="<?php echo $re;?>" <?php echo $checked;?> />&nbsp;
					<?php echo $lang['resource'][$module_prefix]['set'][$re];?><br />
				</p>
				<?php
				endforeach;
				?>		
				<?php }?>
				
				
				<hr />
							
				<p align="right">
					<?php
					if (isset($allow_spellcheck)) {
					?>
					<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
					<?php }?>
					
					<input type="submit" name="save_set" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
					<br />
				</p>
			</div>
		</div>
	</div>

	<?php
	if (isset($set)) {
	?>
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_ownership'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				
				<p>
					<?php echo $lang['txt_owner_intro'];?><br />
				</p>
				
				<?php
				if (isset($editors)) {
				?>
				<p>
					<label for="id_user_id"><?php echo $lang['txt_new_owner'];?></label>
					<select id="id_user_id" name="user_id" style="width:160px;">
						<?php
						foreach ($editors as $key => $i):
						?>
						<option value="<?php echo $i['user_id'];?>"><?php echo $i['identity_nic'];?></option>
						<?php
						endforeach;
						?>
					</select>
				</p>
				
				<hr />
					
				<p align="right">
					<input name="update_ownership" type="submit" class="input_submit" value="<?php echo $lang['sub_resign'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	<?php }?>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_starting_a_set'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_wiki_set_create_intro'];?><br />
				</p>

				<?php
				if (isset($set)) {
				?>
				<ul>
					<li><a href="index.php?amn=core_stylesheet_edit&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;item_id=<?php echo $set['set_id'];?>"><?php echo $lang['href_stylesheet'];?></a></li>
				</ul>
				<?php }?>
			</div>
		</div>
	</div>

	<?php
	if (isset($set)) {
	?>
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_tags'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_tags'];?></b><br />
					<?php
					if (isset($tags)) {
					$prnt = "";
					foreach($tags as $key => $i):
						$prnt .= $i['tag_body'] . "<sup><a href='index.php?amn=lbr_set_edit&amp;set_id=" . $set['set_id'] . "&amp;edit_tag=" . $i['tag_id'] . "&amp;user_id=" . $i['item_id'] . "' style='text-decoration:none;'>&#43;</a></sup> ";
					endforeach;
					echo $prnt;
					}
					?>
				</p>
				
				<table cellspacing="1" cellpadding="0" border="0" width="100%">
					<tr>
						<td>
							<input type="hidden" name="tag_id" value="<?php if (isset($tag)) { echo $tag['tag_id'];}?>" />
							<input type="text" class="input1" name="tag_body" size="10" value="<?php if (isset($tag)) { echo $tag['tag_body'];}?>" /><br />
						</td>	
						<td nowrap="nowrap" align="right">
							<input type="submit" name="insert_tag" class="input_submit" style="font-size:60%;" value="OK" /> 
							<input type="submit" name="delete_tag" class="input_submit" style="font-size:60%;" value="DEL" /><br />
						</td>					
					</tr>				
				</table>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_page_default'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($pages)) {
				?>
				<table cellspacing="2" cellpadding="2" width="100%" border="0">
					<?php
					foreach ($pages as $key => $i):
					?>
					<tr>
						<td valign="top">
							<b><?php echo $i['page_title'];?></b><br />
							<?php echo $i['page_name'];?><br />
						</td>
						<td valign="top">
							<?php
							$checked = "";
							
							if ($set['default_page_id'] == $i['page_id']) {
								$checked = "checked=\"checked\"";
							}
							?>
							<input type="radio" name="default_page_id" value="<?php echo $i['page_id'];?>" <?php echo $checked;?> /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="set_default_page_id" class="input_submit" value="<?php echo $lang['sub_default_page_id'];?>" />
					<br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
<?php }?>
</div>		
</form>
